@@ -106,7 +106,7 @@ cast_simple <- function(data=NULL, columns=NULL, rows=NULL, values=NULL) {
 #' if \code{NULL}, uses all variable names in \code{DT}
 #' @export na2zero
 #' @details Given a \code{data.table} object, converts \code{NA} values
-#' to numeric (double) zeroes for all variables named in \code{vars} or
+#' to numeric (double) zeros for all variables named in \code{vars} or
 #' all variables if \code{vars = NULL}.
 na2zero = function(DT, vars = NULL) { 
   if (!is.data.table(DT)) stop("DT must be a data.table")
@@ -387,7 +387,7 @@ cut_bound <- function(t, factor=TRUE) {
 
 
 
-#' @title Set the class of an object (convencience function for
+#' @title Set the class of an object (convenience function for
 #'  \code{setattr(obj, "class", CLASS)}); can add instead of replace
 #' @description Sets the class of an object in place to \code{cl}
 #' by replacing or adding
@@ -1330,10 +1330,48 @@ breaks_in_data <- function(br, ts, data) {
 
 
 
+is_named_list <- function(x) is.list(x) && length(unique(names(x))) == length(x)
 
 
 
 
+fuse_breakslists <- function(bl.old, bl.new, drop) {
+  # @description given two lists of breaks, uses all timescales found
+  # in both lists to fuse into one list. For common timescales an 
+  # interval-based subset is taken, so that the new always limits the old
+  # when drop = TRUE.
+  
+  stopifnot(
+    is_named_list(bl.old), is_named_list(bl.new)
+  )
+  
+  bl <- bl.old
+  new_scales <- setdiff(names(bl.old), names(bl.new))
+  if (length(new_scales)) {
+    bl[new_scales] <- bl.new[new_scales]
+  }
+  common_scales <- intersect(names(bl.old), names(bl.new))
+  if (length(common_scales)) {
+    
+    bl[common_scales] <- lapply(common_scales, function(time_scale) {
+      new <- bl.new[[time_scale]]
+      old <- bl.old[time_scale]
+      fuse <- sort(union(old, new))
+      if (drop) {
+        r.new <- range(new)
+        r.old <- range(old)
+        r <- c(max(r.new[1], r.old[1]), min(r.new[2], r.old[2]))
+        fuse <- fuse[between(fuse, r[1], r[2], incbounds = TRUE)]
+      }
+      fuse
+    })
+    
+  }
+  
+  bl
+  
+}
+
 
 
 
